# FHIR-TO-OMOP Install Package

Date: 2024-12-16

## Contact

- MiHUBx Team [info@mihubx.de](mailto:info@mihubx.de?subject=Technischer%20Support)

## Description

This `FHIR-TO-OMOP Package` is part of the `Service Platform Prototype` and refers to **Hoffmann et al.** *"Streamlining Intersectoral Provision of Real-World Health Data: A Service Platform for Improved Clinical Research and Patient Care"*, Manuscript in preparation for publication in Frontiers in Medicine (2023). 

**This package is intended to provide interfaces and services to transform real-world health data to the Observational Medical Outcomes Partnership (OMOP) Common Data Model (CDM) and contains the following components, see Figure 1.**

- **OMOP Database** (*service:* `omopdb`): A PostgreSQL database with a database scheme according to the OMOP CDM.
- **OHDSI WebAPI** (*service:* `webapi`): contains all OHDSI RESTful services that can be called from OHDSI applications (cf. [https://github.com/OHDSI/WebAPI](https://github.com/OHDSI/WebAPI)).
- **OHDSI Atlas** (*service:* `atlas`): A web-based tool for scientific analysis (cf. [https://github.com/OHDSI/Atlas](https://github.com/OHDSI/Atlas))
- **Initialization of OMOP Database** (*service:* `init-omopdb`): Initialization of the OMOP CDM including loading of the german vocabularies (cf. [https://gitlab.ukdd.de/pub/ohdsi/techstack](https://gitlab.ukdd.de/pub/ohdsi/techstack)).
- **FHIR-TO-OMOP** (*service:* `ohdsi-germany`): An ETL process that extracts data from the *FHIR Server BLAZE*, transforms and loads it to the *OMOP CDM* (cf. [https://gitlab.ukdd.de/pub/etl/fhir-to-omop](https://gitlab.ukdd.de/pub/etl/fhir-to-omop)).
- **OHDSI ACHILLES** (*service:* `start-achilles`): A tool for data characterization and visualization (cf. [https://github.com/OHDSI/Achilles](https://github.com/OHDSI/Achilles)).
- **OHDSI Data Quality Dashboard (DQD)** (*service:* start-dqd): A tool to expose and evaluate observational data quality (cf. [https://github.com/OHDSI/DataQualityDashboard](https://github.com/OHDSI/DataQualityDashboard))


![researchdata-to-fhir](imgs/packages.jpg)

**Figure 1. Services and data flows.** The Clinical Data Repository (CDR) is site-specific and stores real-world data (RWD) from routine clinical care. The data is extracted from the CDR, transformed to the MII Core dataset format and loaded into the Research Data Repository (RDR) via the site-specific ETL-process CDR-to-RDR (**Step 1**). During this process, the TRANSITION Database can optionally be used to support semantic data mapping and the Structural Mapping Guideline to support structural mapping. The RDR-to-FHIR ETL-process (**Step 2**) extracts the data from the RDR, constructs FHIR resources and loads them onto the FHIR server BLAZE that can be protected by the Authentication Server KEYCLOAK. RDR, RDR-to-FHIR and, FHIR Server BLAZE are provided by the [ResearchData-TO-FHIR Install Package](https://gitlab.ukdd.de/pub/mihubx/researchdata-to-fhir-install-pkg) and TRANSITION Database, the Authentication Server KEYCLOAK as well as pgAdmin and Portainer are provided by the [Addons Package](https://gitlab.ukdd.de/pub/mihubx/addons-install-pkg) of the Service Platform. The [FHIR-TO-OMOP Package](https://gitlab.ukdd.de/pub/mihubx/fhir-to-omop-install-pkg) of the Service Platform includes the FHIR-to-OMOP ETL-process (**Step 3**), which is used to extract the FHIR resources from the FHIR Server BLAZE, transform the FHIR resources into the OMOP CDM format and load them into the OMOP CDM database. Based on the OMOP CDM data format, data characterization and visualization can be performed by using ACHILLES, data analysis by ATLAS and data quality assessment by using DQD, which is also provided by the FHIR-TO-OMOP Package of the Service Platform.

## Intended Purpose

This medical software is designed exclusively for research purposes and may not be used in a clinical or therapeutic context. It is used to analyse, process and visualise medical data in order to investigate scientific questions, test hypotheses and support medical research. The software is not authorised for use in the diagnosis, treatment or monitoring of patients. Any use in connection with direct patient care, including decision-making in the context of diagnosis or therapy, is strictly prohibited.

Users of the software are obliged to ensure that the data collected is only used for scientific purposes and processed in accordance with the applicable data protection regulations. All results obtained through the use of the software are purely exploratory in nature and may not be used as a basis for clinical decisions.

The software must be used by qualified personnel who are familiar with the applicable ethical guidelines and regulatory requirements in the field of medical research.

**Important notes:**

- This software is not subject to certification according to the Medical Device Regulation (MDR).
- The results of the software may not be used or interpreted for patient treatment.
- The manufacturer accepts no liability in the event of misuse.

By using the software, users declare that they agree to the terms of use stated here and confirm that they will use the software exclusively for research purposes.

## Instruction for installation and operation

[Dependencies and Requirements](docs/PREPARATION.md)

[Installation Instructions](docs/INSTALLATION.md)

## Everything worked?

We would be very pleased if you would give us your feedback. We greatly appreciate your participation in our [survey](https://www.soscisurvey.de/FHIR_to_OMOP/). This evaluation is of great importance for the practical development of our service and its continuous improvement.

## Support
If you have any questions or recommendations please contact the [MiHUBx Team](mailto:info@mihubx.de?subject=Technischer%20Support).

[Troubleshooting](docs/troubleshooting.md)

## Sources
This installation package is just an aggregation of different installation packages. In case of technical problems, please contact the maintainers of the sub-packages directly:
- [ResearchData-TO-FHIR Package](https://gitlab.ukdd.de/pub/mihubx/researchdata-to-fhir-install-pkg)
- [fhir-to-omop](https://gitlab.ukdd.de/pub/etl/fhir-to-omop)
- [ohdsi-omop-v5](https://gitlab.ukdd.de/pub/ohdsi)


## Authors and acknowledgment
- Cigdem Klengel
- Katja Hoffmann

We acknowledge:
- Maik Löwe and Henri Wahl, who supported us with infrastructure and security issues.

## License
The Addons Install Package is licensed under the GNU GPLv3 license. See [LICENSE](./LICENSE) for reference.

The Addons Install Package also contains code from open source projects. See [ATTRIBUTIONS.md](./ATTRIBUTIONS.md) for a list.

## Project status
active
