[Overview](../README.md)

# Installation

## Quickstart for Experts
*If you are a beginner, please continue reading under Detailed installation instructions for beginners. ([Detailled Installation Guide for Beginners](#detailled-installation-guide-for-beginners))*

Make sure that [ResearchData-TO-FHIR Package](https://gitlab.ukdd.de/pub/mihubx/researchdata-to-fhir-install-pkg) has been completed successfully and the data is available in the FHIR server. For a quick test you can use the testdata from [ResearchData-TO-FHIR Package](https://gitlab.ukdd.de/pub/mihubx/researchdata-to-fhir-install-pkg/-/blob/main/docs/testing.md).

>**Note:** Use main branch only for testing purposes. Please use the recent stable [release](https://gitlab.ukdd.de/pub/mihubx/fhir-to-omop-install-package/-/releases).

### Configuration
In order to adapt the installed services to the local conditions, the `.env.example` and the `ohdsi-omop-v5/config-local.js.example` must be copied and its variables adjusted to your environment.
```
cp .env.example .env
cp ohdsi-omop-v5/config-local.js.example ohdsi-omop-v5/config-local.js
```
>**Note:** Please make sure that the network variable from the .env of the [RDR-TO-FHIR](https://gitlab.ukdd.de/pub/mihubx/researchdata-to-fhir-install-pkg) must be identical to that of this installation package.

Example:
```
# GENERAL Conf from rdr-to-fhir-install-pkg/.env.example
DOCKER_NETWORK=spp
```

```
# GENERAL Conf from fhir-to-omop-install-pkg/.env.example
DOCKER_NETWORK=spp
```

In addition to the adjustments in the .env file, the URL in config-local.js (path: ohdsi-omop-v5/config-local.js ) may need to be changed, depending on your hostname.
```
  // WebAPI
  configLocal.api = {
    name: "OHDSI",
    url: 'http://localhost:9876/WebAPI/'
  };
```


### Run it
After downloading this repo, navigate to the project folder and run docker compose with profile `init` to start the OMOP initialization.

```
docker compose --profile init up -d
```

After terminating the init-omopdb service (the container is terminated with code 0), you can start the ETL process, including Achilles and the Data Quality Dashboard with docker compose with profile `etl`.

```
docker compose --profile etl up -d
```

**Alternatively, you can perform the setup step by step, which is described in [MANUAL_SETUP](MANUAL_SETUP.md) .**

## Detailled Installation Guide for Beginners
### Step 0
Make sure that [RDR-TO-FHIR](https://gitlab.ukdd.de/pub/mihubx/researchdata-to-fhir-install-pkg) has been completed successfully and the data is available in the FHIR server. Therefore follow the steps in the [installation instructions](https://gitlab.ukdd.de/pub/mihubx/researchdata-to-fhir-install-pkg/-/blob/main/docs/installation_instructions.md) before you start with step 1.

### Step 1
If you have followed the [instructions](https://gitlab.ukdd.de/pub/mihubx/researchdata-to-fhir-install-pkg/-/blob/main/docs/installation_instructions.md) up to and including point 1, you have a project folder on your server.
Now clone the repository in this specific folder.
>**Note:** Use main branch only for testing purposes. Please use the recent stable [release](https://gitlab.ukdd.de/pub/mihubx/fhir-to-omop-install-package/-/releases).
```
git clone https://gitlab.ukdd.de/pub/mihubx/fhir-to-omop-install-package --branch <recent-release>
```

### Step 2
Go to the newly created folder.
```
cd fhir-to-omop-install-pkg
```
Copy file `.env.example` and rename it to `.env`
```
cp .env.example .env
```
Now you can customize `.env` according to your environment. To open the file you can use tools like `vim` or `nano`.
```
vim .env
```
Adjust at least the variables COMPOSE_PROJECT_NAME and if necessary the TCP/IP ports of the docker containers and HOSTNAME, credentials of the database.
```
COMPOSE_PROJECT_NAME=project1
HOSTNAME=http://localhost
```
Exit the `.env` with `wq` or `CTR+X` and save with `Y` when using `vim`.

Copy file `ohdsi-omop-v5/config-local.js.example` and rename it to `ohdsi-omop-v5/config-local.js`
```
cp ohdsi-omop-v5/config-local.js.example ohdsi-omop-v5/config-local.js
```

In addition to the adjustments in the .env file, the URL in `config-local.js` may need to be changed, depending on your hostname.
```
nano ohdsi-omop-v5/config-local.js
```

```
  // WebAPI
  configLocal.api = {
    name: "OHDSI",
    url: 'http://localhost:9876/WebAPI/'
  };
```

Create a folder for the Data Quality Dashboard output and set the owner as follows. For further information, see [check the installation](https://gitlab.ukdd.de/pub/ohdsi/techstack#step-6---check-data-quality-with-ohdsi-dataqualitydashboard)
```
mkdir ohdsi-omop-v5/dqd_output
sudo chown 999:999 ohdsi-omop-v5/dqd_output
```

### Step 3
After completing the preparations and configurations, you can proceed with the OMOP initialization and execute the ETL process independently.
For setting up up OMOP, Atlas and WebAPI, and OMOP initialization execute docker compose with profile `init`.
```
docker compose --profile init up -d
```
>**Note:** It is expected that this process takes between **50 to 70 minutes!** So don't abort this process! The `init-omopdb` container will enter the exit state once this process has been completed.

### Step 4
After terminating the init-omopdb service (the container is terminated with code 0), you can start the ETL process, including Achilles and the Data Quality Dashboard with docker compose with profile `etl`.

```
docker compose --profile etl up -d
```
>**Note:** The ETL process FHIR-to-OMOP is executed. Depending on the dataset, this process can take up to **20 minutes**. Once the process is complete, Achilles is executed automatically. Once the Achilles process has been completed, the Data Quality Dashboard is executed automatically.

>**Note:** Depending on your customizations in the configuration file, you may receive warnings that variables are not set. This does not necessarily lead to problems during the installation process. The installation is only cancelled if mandatory variables have not been set. You can ignore Warnings like

![Warnings to ignore](../imgs/warnings.png)


## Finally Finished...?
When the huge process is finished, the containers `init-omopdb`, `ohdsi-germany` and `start-achilles` should be in exit status 0 and `omopdb`, `atlas`, `webapi` and `start_dqd` should be in running status.
Depending on the configuration of your environment and your hostname (e.g. localhost on local machines), you can access Atlas and the WebAPI like:
| Application | URL                           |
| ----------- | ----------------------------- |
| **Atlas**   | <http://localhost:8080/atlas>       |
| **WebAPI**  | <http://localhost:9876/WebAPI/info>       |
| **DQD**  | <http://localhost:3838>       |

or have a closer look at [check the installation](https://gitlab.ukdd.de/pub/ohdsi/techstack#step-4-check-the-installation).

When using the [test data](https://gitlab.ukdd.de/pub/mihubx/researchdata-to-fhir-install-pkg/-/blob/main/docs/testing.md), you should see the following view in the Atlas.

![Atlas view](../imgs/atlas_view.png)

... and the following view in the Data Quality Dashboard (DQD).
![DQD view](../imgs/dqd_view.png)