[Overview](../README.md)

# Manual Setup Documentation
This guide provides step-by-step instructions to manually set up the OMOP database and related components using Docker Compose.

## Prerequisites
Ensure you have customized the `.env` file and the `ohdsi-omop-v5/config-local.js` and create folder `ohdsi-omop-v5/dqd_output` and set its ownership as described in the [Installation](INSTALLATION.md#configuration) file und section `Configuration`.

## Step 1: Install OMOP Database
Start the OMOP database container:

```bash
docker compose -f docker-compose-manual-setup.yml up omopdb -d
```

Check the container logs to confirm the database setup is complete. The setup finishes when the container log display: "database system is ready to accept connections".


## Step 2: Deploy WebAPI
Start the WebAPI container:

```bash
docker compose -f docker-compose-manual-setup.yml up webapi -d
```

Wait until the logs show: "Finishing tags statistics refreshing"


## Step 3: Deploy Atlas
Start the Atlas container:

```bash
docker compose -f docker-compose-manual-setup.yml up atlas -d
```

Ensure the logs display: "Configuration complete; ready for start up"

## Step 4: Initialize the OMOP Database
Run the initialization process for the OMOP database:

```bash
docker compose -f docker-compose-manual-setup.yml up init-omopdb -d
```

The initialization process is successfully finished when the container automatically stops with an exit code of `0`. The container log display: "Completed initialization."
Note that this process can take up to 60 minutes.

You can access ATLAS with something like: `http://localhost:8080/atlas`.

## Step 5: Start FHIR-to-OMOP ETL Process
Before starting the OHDSI-Germany container, ensure that the FHIR server is populated with data.

```bash
docker compose -f docker-compose-manual-setup.yml up ohdsi-germany -d
```

The etl process is successfully finished when the container automatically stops with an exit code of `0`. The container log display: "Job End"
Note that this process may take some time depending on the amount of data.

## Step 6: Start ACHILLES
Run the data characterization process:

```bash
docker compose -f docker-compose-manual-setup.yml up start-achilles -d
```

The characterization process is successfully finished when the container automatically stops with an exit code of `0`. After this process, the metrics are availabe via ATLAS.
You can access ATLAS with something like: `http://localhost:8080/atlas`.

## Step 7: Deploy Data Quality Dashbord
Start the Data Quality Dashboard.

```bash
docker compose -f docker-compose-manual-setup.yml up start-dqd -d
```

Wait until the container log show: "Listening on http://0.0.0.0:3838".

You can access the Data Quality Dashboard with something like: `http://localhost:3838`.